#!/usr/bin/env node
"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const path_1 = __importDefault(require("path"));
const fs_extra_1 = __importDefault(require("fs-extra"));
const commander_1 = require("commander");
const lessgen_1 = __importDefault(require("./scripts/lessgen"));
const docgen_1 = __importDefault(require("./scripts/docgen"));
const dtsgen_1 = __importDefault(require("./scripts/dtsgen"));
const dev_component_1 = __importDefault(require("./scripts/dev-component"));
const site_1 = __importDefault(require("./scripts/site"));
const build_project_1 = __importDefault(require("./scripts/build-project"));
const build_app_1 = __importDefault(require("./scripts/build-app"));
const build_component_1 = __importDefault(require("./scripts/build-component"));
const build_style_1 = __importDefault(require("./scripts/build-style"));
const build_library_1 = __importDefault(require("./scripts/build-library"));
const changelog_1 = __importDefault(require("./scripts/changelog"));
const jsongen_1 = __importDefault(require("./scripts/jsongen"));
const program = new commander_1.Command();
const packageContent = fs_extra_1.default.readFileSync(path_1.default.resolve(__dirname, '../package.json'), 'utf8');
const packageData = JSON.parse(packageContent);
program.version(packageData.version).name('ent-vue-scripts').usage('command [options]');
program
    .command('docgen')
    .description('generate document of component. e.g. arco-scripts-vue docgen --components menu,affix,button')
    .option('-i, --input <filename>', 'specified input file')
    .option('-c, --components <names>', 'component name(s) joined by comma(,)')
    .action(({ input, components }) => {
    components = typeof components === 'string' ? components.split(',') : [];
    (0, docgen_1.default)({ input, components });
});
program
    .command('lessgen')
    .description('generate index less file.')
    .action(() => {
    (0, lessgen_1.default)();
});
program
    .command('dtsgen')
    .option('--lib', 'build type for library')
    .description('emit .d.ts files for vue files.')
    .action(({ lib }) => {
    (0, dtsgen_1.default)(lib);
});
program
    .command('dev:component')
    .description('build components with watch mode.')
    .action(async () => {
    await (0, dev_component_1.default)();
});
program
    .command('dev:site')
    .description('start vite server for site development.')
    .option('-p --port <port>', `[number] specify port`, '5000')
    .action(async ({ port }) => {
    await (0, site_1.default)({ command: 'serve', mode: 'development' }, port);
});
program
    .command('dev:project')
    .description('start vite server for project development.')
    .option('-p --port <port>', `[number] specify port`, '5500')
    .action(async ({ port }) => {
    await (0, build_project_1.default)({ command: 'serve', mode: 'development' }, port);
});
program
    .command('build:component')
    .description('build production files.')
    .option('-u, --umd', 'build with UMD file')
    .action(async ({ umd }) => {
    await (0, build_component_1.default)({ umd });
});
program
    .command('build:library')
    .description('build library')
    .option('-u, --umd', 'build with UMD file')
    .option('-s, --source', 'build with library source')
    .option('--base', 'build with library source')
    .action(async ({ umd, source, base }) => {
    await (0, build_library_1.default)({ umd, source, base });
});
program
    .command('build:style')
    .description('build style related files.')
    .option('-M, --material', 'generate style for material')
    .action(async () => {
    await (0, build_style_1.default)();
});
program
    .command('build:site')
    .description('build document site.')
    .action(async () => {
    await (0, site_1.default)({ command: 'build', mode: 'production' }, -1);
});
program
    .command('build:project')
    .description('build project.')
    .action(async () => {
    await (0, build_project_1.default)({ command: 'build', mode: 'production' }, -1);
});
program
    .command('build:app')
    .description('package the app.')
    .action(async () => {
    await (0, build_app_1.default)();
});
program
    .command('changelog')
    .description('Obtain and organize changelog information through the git repository.')
    .action(async () => {
    await (0, changelog_1.default)();
});
program
    .command('jsongen')
    .description('generate vetur and web-types json files')
    .action(async () => {
    await (0, jsongen_1.default)();
});
program.parse(process.argv);
//# sourceMappingURL=cli.js.map