"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.defineAppConfig = void 0;
const pkg_types_1 = require("pkg-types");
const vite_1 = require("vite");
const vite_plugin_dts_1 = __importDefault(require("vite-plugin-dts"));
const plugins_1 = require("../plugins");
const modify_vars_1 = require("../utils/modify-vars");
const common_1 = require("./common");
/***
 * app 模式 - 打包到 es/lib
 */
async function defineAppConfig(defineOptions) {
    const { overrides = {} } = defineOptions;
    const { command, mode } = defineOptions;
    const root = process.cwd();
    const plugins = await (0, plugins_1.createPlugins)({
        isBuild: true,
        mode: 'lib',
        root,
        enableAnalyze: false,
        enableMock: false,
        compress: 'none',
    });
    const { dependencies = {}, peerDependencies = {} } = await (0, pkg_types_1.readPackageJSON)(root);
    const deps = [...Object.keys(dependencies), ...Object.keys(peerDependencies)];
    let entDeps = [];
    if (deps.includes('fe-ent-core')) {
        const { dependencies: entDependencies = {}, peerDependencies: entPeerDependencies = {} } = await (0, pkg_types_1.readPackageJSON)(`${root}/node_modules/fe-ent-core`);
        entDeps = [...Object.keys(entDependencies), ...Object.keys(entPeerDependencies)];
    }
    const packageConfig = {
        build: {
            lib: {
                entry: 'index.ts',
                formats: ['es', 'cjs'],
                fileName: (format, entryName) => {
                    return `${entryName}.${format === 'cjs' ? 'js' : 'mjs'}`;
                },
            },
            rollupOptions: {
                external: [...deps, ...entDeps],
            },
        },
        css: {
            preprocessorOptions: {
                less: {
                    modifyVars: (0, modify_vars_1.generateModifyVars)(),
                    javascriptEnabled: true,
                },
            },
        },
        plugins: [
            ...plugins,
            (0, vite_plugin_dts_1.default)({
                entryRoot: `${root}`,
                include: ['index.ts', 'components/**/*.{ts,tsx,vue}'],
                outputDir: `${root}/dist/types`,
                logLevel: 'error',
            }),
        ],
    };
    const mergedConfig = (0, vite_1.mergeConfig)((0, common_1.commonConfig)({ command, mode }), packageConfig);
    return (0, vite_1.mergeConfig)(mergedConfig, overrides);
}
exports.defineAppConfig = defineAppConfig;
//# sourceMappingURL=app.js.map