"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.defineLibraryConfig = void 0;
const pkg_types_1 = require("pkg-types");
const vite_1 = require("vite");
const vite_plugin_dts_1 = __importDefault(require("vite-plugin-dts"));
const fast_glob_1 = __importDefault(require("fast-glob"));
const plugins_1 = require("../plugins");
const modify_vars_1 = require("../utils/modify-vars");
const vite_plugin_vue_export_helper_1 = __importDefault(require("../plugins/vite-plugin-vue-export-helper"));
const vite_plugin_external_1 = __importDefault(require("../plugins/vite-plugin-external"));
const exclude_files_1 = require("../utils/exclude-files");
const common_1 = require("./common");
/***
 * Library 模式
 */
async function defineLibraryConfig(source) {
    const root = process.cwd();
    const plugins = await (0, plugins_1.createPlugins)({
        isBuild: true,
        mode: 'lib',
        root,
        enableAnalyze: false,
        enableMock: false,
        compress: 'none',
    });
    const { dependencies = {}, peerDependencies = {} } = await (0, pkg_types_1.readPackageJSON)(root);
    const deps = [...Object.keys(dependencies), ...Object.keys(peerDependencies)];
    const input = (0, exclude_files_1.excludeFiles)(fast_glob_1.default.sync('**/*.{ts,tsx,vue}', {
        cwd: process.cwd(),
        absolute: false,
        onlyFiles: true,
    })).map((file) => `${process.cwd()}/${file}`);
    const packageConfig = {
        build: {
            target: 'modules',
            outDir: 'es',
            emptyOutDir: false,
            minify: false,
            sourcemap: true,
            lib: {
                entry: 'index.ts',
                formats: ['es', 'cjs'],
                fileName: (format, entryName) => {
                    return `${entryName}.${format === 'cjs' ? 'js' : 'mjs'}`;
                },
            },
            rollupOptions: {
                input,
                output: [
                    {
                        interop: 'default',
                        format: 'es',
                        dir: 'es',
                        entryFileNames: '[name].mjs',
                        preserveModules: true,
                        exports: 'named',
                        //preserveModulesRoot: 'components',
                    },
                    {
                        interop: 'auto',
                        format: 'commonjs',
                        dir: 'lib',
                        entryFileNames: '[name].js',
                        preserveModules: true,
                        exports: 'named',
                        //preserveModulesRoot: 'components',
                    },
                ],
                external: [...deps],
                // output: {
                //   exports: 'named',
                // },
            },
        },
        css: {
            preprocessorOptions: {
                less: {
                    modifyVars: (0, modify_vars_1.generateModifyVars)(),
                    javascriptEnabled: true,
                },
            },
        },
        plugins: [
            (0, vite_plugin_external_1.default)(source),
            ...plugins,
            (0, vite_plugin_dts_1.default)({
                entryRoot: `${root}`,
                include: ['**/*.{ts,tsx,vue}'],
                outputDir: [`${root}/es/`, `${root}/lib/`],
                logLevel: 'error',
            }),
            (0, vite_plugin_vue_export_helper_1.default)(),
        ],
    };
    const mergedConfig = (0, vite_1.mergeConfig)((0, common_1.commonConfig)({ command: 'build', mode: 'production' }), packageConfig);
    return mergedConfig;
}
exports.defineLibraryConfig = defineLibraryConfig;
//# sourceMappingURL=library.js.map