"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.defineUmdLibraryConfig = void 0;
const pkg_types_1 = require("pkg-types");
const vite_1 = require("vite");
const plugin_terser_1 = __importDefault(require("@rollup/plugin-terser"));
const plugins_1 = require("../plugins");
const modify_vars_1 = require("../utils/modify-vars");
const vite_plugin_external_1 = __importDefault(require("../plugins/vite-plugin-external"));
const common_1 = require("./common");
/***
 * Library 模式
 */
async function defineUmdLibraryConfig(source, base) {
    const root = process.cwd();
    const packageJson = await (0, pkg_types_1.readPackageJSON)(root);
    const { name } = packageJson;
    const plugins = await (0, plugins_1.createPlugins)({
        isBuild: true,
        mode: 'lib',
        root,
        enableAnalyze: false,
        enableMock: false,
        compress: 'none',
    });
    const { dependencies = {}, peerDependencies = {} } = await (0, pkg_types_1.readPackageJSON)(root);
    const deps = [...Object.keys(dependencies), ...Object.keys(peerDependencies)];
    const packageConfig = {
        base,
        build: {
            target: 'modules',
            outDir: 'dist',
            emptyOutDir: false,
            sourcemap: true,
            minify: false,
            cssMinify: true,
            rollupOptions: {
                input: ['index.ts'],
                output: [
                    {
                        format: 'umd',
                        entryFileNames: `index.full.js`,
                        exports: 'named',
                        name,
                    },
                    {
                        format: 'umd',
                        entryFileNames: `index.full.min.js`,
                        exports: 'named',
                        name,
                        plugins: [(0, plugin_terser_1.default)()],
                    },
                ],
                external: [...deps],
            },
            lib: {
                entry: 'index.ts',
                formats: ['umd'],
                fileName: (format, entryName) => {
                    return `${entryName}.${format === 'cjs' ? 'js' : 'mjs'}`;
                },
            },
        },
        css: {
            preprocessorOptions: {
                less: {
                    modifyVars: (0, modify_vars_1.generateModifyVars)(),
                    javascriptEnabled: true,
                },
            },
        },
        plugins: [(0, vite_plugin_external_1.default)(source), ...plugins],
    };
    const mergedConfig = (0, vite_1.mergeConfig)((0, common_1.commonConfig)({ command: 'build', mode: 'production' }), packageConfig);
    return mergedConfig;
}
exports.defineUmdLibraryConfig = defineUmdLibraryConfig;
//# sourceMappingURL=library.umd.js.map