"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.defineProjectConfig = void 0;
const node_path_1 = require("node:path");
const dayjs_1 = __importDefault(require("dayjs"));
const pkg_types_1 = require("pkg-types");
const vite_1 = require("vite");
const plugins_1 = require("../plugins");
const modify_vars_1 = require("../utils/modify-vars");
const env_1 = require("../utils/env");
const common_1 = require("./common");
async function defineProjectConfig(defineOptions) {
    const { overrides = {} } = defineOptions;
    const { command, mode } = defineOptions;
    const root = process.cwd();
    const isBuild = command === 'build';
    const env = (0, vite_1.loadEnv)(mode, root);
    const { VITE_BUILD_USE_MOCK, VITE_BUILD_COMPRESS, VITE_BUILD_ENABLE_ANALYZE, VITE_BUILD_ENABLE_INSPECT, VITE_BUILD_ENABLE_CERT, } = env;
    const viteEnv = (0, env_1.wrapperEnv)(env, mode);
    const defineData = await createDefineData(root, viteEnv);
    const plugins = await (0, plugins_1.createPlugins)({
        isBuild,
        mode: isBuild ? 'build' : 'dev',
        root,
        enableAnalyze: VITE_BUILD_ENABLE_ANALYZE === 'true',
        enableMock: VITE_BUILD_USE_MOCK === 'true',
        enableInspect: VITE_BUILD_ENABLE_INSPECT === 'true',
        enableCert: VITE_BUILD_ENABLE_CERT === 'true',
        compress: VITE_BUILD_COMPRESS,
    });
    const pathResolve = (pathname) => (0, node_path_1.resolve)(root, '.', pathname);
    const alias = [];
    alias.push(...[
        {
            find: /\/@\//,
            replacement: `${pathResolve('src')}/`,
        },
        // @/xxxx => src/xxxx
        {
            find: /@\//,
            replacement: `${pathResolve('src')}/`,
        },
    ]);
    // if (isBuild) {
    //   alias.push({ find: 'vue-router', replacement: 'vue-router/dist/vue-router.prod.cjs' });
    // } else {
    //   alias.push({ find: 'vue-router', replacement: 'vue-router/dist/vue-router.cjs' });
    // }
    const applicationConfig = {
        resolve: {
            alias,
        },
        define: defineData,
        build: {
            target: 'es2015',
            cssTarget: 'chrome80',
            rollupOptions: {
                output: {
                    manualChunks: {
                        vue: ['vue', 'pinia', 'vue-router'],
                        antv: ['ant-design-vue'],
                        antd: ['@ant-design/icons-vue'],
                    },
                },
            },
        },
        css: {
            preprocessorOptions: {
                less: {
                    modifyVars: (0, modify_vars_1.generateModifyVars)(defineOptions.options?.cssModify),
                    javascriptEnabled: true,
                },
            },
        },
        plugins,
    };
    const mergedConfig = (0, vite_1.mergeConfig)((0, common_1.commonConfig)({ command, mode }), applicationConfig);
    return (0, vite_1.mergeConfig)(mergedConfig, overrides);
}
exports.defineProjectConfig = defineProjectConfig;
async function createDefineData(root, viteEnv) {
    try {
        const pkgJson = await (0, pkg_types_1.readPackageJSON)(root);
        const { dependencies, devDependencies, name, version } = pkgJson;
        const __APP_INFO__ = {
            pkg: { dependencies, devDependencies, name, version },
            lastBuildTime: (0, dayjs_1.default)().format('YYYY-MM-DD HH:mm:ss'),
        };
        return {
            'process.env': viteEnv,
            __APP_INFO__: JSON.stringify(__APP_INFO__),
        };
    }
    catch {
        return {};
    }
}
//# sourceMappingURL=project.js.map