"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const fast_glob_1 = __importDefault(require("fast-glob"));
const plugin_vue_1 = __importDefault(require("@vitejs/plugin-vue"));
const plugin_vue_jsx_1 = __importDefault(require("@vitejs/plugin-vue-jsx"));
const vite_plugin_external_1 = __importDefault(require("../plugins/vite-plugin-external"));
const vite_plugin_vue_export_helper_1 = __importDefault(require("../plugins/vite-plugin-vue-export-helper"));
const exclude_files_1 = require("../utils/exclude-files");
const modify_vars_1 = require("../utils/modify-vars");
const input = (0, exclude_files_1.excludeFiles)(fast_glob_1.default.sync('**/*.{ts,tsx,vue}', {
    cwd: process.cwd(),
    absolute: false,
    onlyFiles: true,
})).map((file) => `${process.cwd()}/${file}`);
const config = {
    mode: 'production',
    build: {
        target: 'modules',
        outDir: 'es',
        emptyOutDir: false,
        minify: false,
        sourcemap: false,
        //brotliSize: false,
        rollupOptions: {
            input: ['index.ts', ...input],
            treeshake: false,
            output: [
                {
                    interop: 'auto',
                    format: 'es',
                    dir: 'es',
                    entryFileNames: '[name].mjs',
                    preserveModules: true,
                    exports: 'named',
                    preserveModulesRoot: `${process.cwd()}`,
                },
                {
                    interop: 'auto',
                    format: 'commonjs',
                    dir: 'lib',
                    entryFileNames: '[name].js',
                    preserveModules: true,
                    exports: 'named',
                    preserveModulesRoot: `${process.cwd()}`,
                },
            ],
        },
        // 开启lib模式，但不使用下面配置
        lib: {
            entry: 'components/index.ts',
            formats: ['es', 'cjs'],
        },
    },
    css: {
        preprocessorOptions: {
            less: {
                modifyVars: (0, modify_vars_1.generateModifyVars)(),
                javascriptEnabled: true,
            },
        },
    },
    resolve: {
        alias: [
            {
                find: /^@ent-core\/(.*)$/,
                replacement: `${process.cwd()}/$1`,
            },
        ],
    },
    // @ts-ignore vite内部类型错误
    plugins: [
        (0, vite_plugin_external_1.default)(),
        (0, plugin_vue_1.default)({
            isProduction: true,
            reactivityTransform: true,
        }),
        (0, plugin_vue_jsx_1.default)(),
        (0, vite_plugin_vue_export_helper_1.default)(),
    ],
};
exports.default = config;
//# sourceMappingURL=vite.prod.js.map