"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.createPlugins = void 0;
const plugin_vue_1 = __importDefault(require("@vitejs/plugin-vue"));
const plugin_vue_jsx_1 = __importDefault(require("@vitejs/plugin-vue-jsx"));
const vite_plugin_purge_icons_1 = __importDefault(require("vite-plugin-purge-icons"));
const vite_plugin_inspect_1 = __importDefault(require("vite-plugin-inspect"));
const vite_plugin_mkcert_1 = __importDefault(require("vite-plugin-mkcert"));
const vite_plugin_app_config_1 = require("./vite-plugin-app-config");
const compress_1 = require("./compress");
const html_1 = require("./html");
const mock_1 = require("./mock");
const svgSprite_1 = require("./svgSprite");
const visualizer_1 = require("./visualizer");
const unocss_1 = require("./unocss");
async function createPlugins({ isBuild, mode, root, enableMock, compress, enableAnalyze, enableInspect, enableCert, }) {
    const vitePlugins = [(0, plugin_vue_1.default)(), (0, plugin_vue_jsx_1.default)()];
    const appConfigPlugin = await (0, vite_plugin_app_config_1.createAppConfigPlugin)({ root, isBuild });
    if (mode !== 'lib') {
        vitePlugins.push(appConfigPlugin);
    }
    if (mode !== 'lib') {
        // vite-plugin-html
        vitePlugins.push((0, html_1.configHtmlPlugin)({ isBuild }));
    }
    // vite-plugin-svg-icons
    vitePlugins.push((0, svgSprite_1.configSvgIconsPlugin)({ isBuild }), (0, vite_plugin_purge_icons_1.default)(), (0, unocss_1.configUnoCSSPlugin)(mode === 'lib'));
    // The following plugins only work in the production environment
    if (isBuild) {
        // rollup-plugin-gzip
        vitePlugins.push((0, compress_1.configCompressPlugin)({
            compress,
        }));
    }
    if (!isBuild && enableInspect) {
        vitePlugins.push((0, vite_plugin_inspect_1.default)());
    }
    if (!isBuild && enableCert) {
        vitePlugins.push((0, vite_plugin_mkcert_1.default)());
    }
    // rollup-plugin-visualizer
    if (mode !== 'lib' && enableAnalyze) {
        vitePlugins.push((0, visualizer_1.configVisualizerConfig)());
    }
    // vite-plugin-mock
    if (mode !== 'lib' && enableMock) {
        vitePlugins.push((0, mock_1.configMockPlugin)({ isBuild }));
    }
    return vitePlugins;
}
exports.createPlugins = createPlugins;
//# sourceMappingURL=index.js.map