"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.createAppConfigPlugin = void 0;
const picocolors_1 = __importDefault(require("picocolors"));
const consola_1 = __importDefault(require("consola"));
const pkg_types_1 = require("pkg-types");
const env_1 = require("../../utils/env");
const hash_1 = require("../../utils/hash");
const GLOBAL_CONFIG_FILE_NAME = '_app.config.js';
const PLUGIN_NAME = 'app-config';
async function createAppConfigPlugin({ root, isBuild, }) {
    let publicPath;
    let source;
    if (!isBuild) {
        return {
            name: PLUGIN_NAME,
        };
    }
    const { version = '' } = await (0, pkg_types_1.readPackageJSON)(root);
    return {
        name: PLUGIN_NAME,
        async configResolved(_config) {
            let appTitle = _config?.env?.VITE_GLOB_APP_SHORT_NAME ?? '';
            appTitle = appTitle.replace(/\s/g, '');
            publicPath = _config.base;
            source = await getConfigSource(appTitle);
        },
        async transformIndexHtml(html) {
            publicPath = publicPath.endsWith('/') ? publicPath : `${publicPath}/`;
            const appConfigSrc = `${publicPath || '/'}${GLOBAL_CONFIG_FILE_NAME}?v=${version}-${(0, hash_1.createContentHash)(source)}}`;
            return {
                html,
                tags: [
                    {
                        tag: 'script',
                        attrs: {
                            src: appConfigSrc,
                        },
                    },
                ],
            };
        },
        async generateBundle() {
            try {
                this.emitFile({
                    type: 'asset',
                    fileName: GLOBAL_CONFIG_FILE_NAME,
                    source,
                });
                consola_1.default.log(picocolors_1.default.cyan(`✨configuration file is build successfully!`));
            }
            catch (error) {
                consola_1.default.log(picocolors_1.default.red(`configuration file configuration file failed to package:\n${error}`));
            }
        },
    };
}
exports.createAppConfigPlugin = createAppConfigPlugin;
/**
 * Get the configuration file variable name
 * @param env
 */
const getVariableName = (title) => {
    return `__PRODUCTION__${title || '__APP'}__CONF__`.toUpperCase().replace(/\s/g, '');
};
async function getConfigSource(appTitle) {
    const config = (0, env_1.wrapperEnv)(await (0, env_1.getEnvConfig)(), 'production');
    const variableName = getVariableName(appTitle);
    const windowVariable = `window.${variableName}`;
    // Ensure that the variable will not be modified
    let source = `${windowVariable}=${JSON.stringify(config)};`;
    source += `
    Object.freeze(${windowVariable});
    Object.defineProperty(window, "${variableName}", {
      configurable: false,
      writable: false,
    });
  `.replace(/\s/g, '');
    return source;
}
//# sourceMappingURL=index.js.map