"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const markdown_1 = require("./markdown");
const descriptor_1 = require("./descriptor");
const utils_1 = require("./utils");
const marked_1 = __importDefault(require("./marked"));
function vueMdPlugin() {
    let vuePlugin;
    const docPlugin = {
        name: 'vite:ent-vue-docs',
        enforce: 'pre',
        configResolved(resolvedConfig) {
            // 获取vue插件，在hotUpload中使用
            vuePlugin = resolvedConfig.plugins.find((p) => p.name === 'vite:vue');
        },
        resolveId(id) {
            // 遇到虚拟md模块，直接返回id
            if ((0, utils_1.isVirtualModule)(id)) {
                return id;
            }
            return null;
        },
        load(id) {
            // 遇到虚拟md模块，直接返回缓存的内容
            if ((0, utils_1.isVirtualModule)(id)) {
                return (0, descriptor_1.getDescriptor)(id);
            }
            return null;
        },
        transform(code, id) {
            if (!id.endsWith('.md')) {
                return null;
            }
            if (!vuePlugin) {
                return this.error('Not found plugin [vite:vue]');
            }
            const transform = 'handler' in vuePlugin.transform ? vuePlugin.transform.handler : vuePlugin.transform;
            if ((0, utils_1.isVirtualModule)(id)) {
                return transform?.call(this, code, (0, utils_1.getVueId)(id));
            }
            const tokens = marked_1.default.lexer(code);
            const frontMatter = (0, utils_1.getFrontMatter)(tokens);
            if (frontMatter?.changelog) {
                return (0, markdown_1.transformChangelog)(tokens);
            }
            const vueCode = (0, utils_1.isDemoMarkdown)(id)
                ? (0, markdown_1.transformDemo)(tokens, id, frontMatter)
                : (0, markdown_1.transformMain)(tokens, id, frontMatter);
            return transform?.call(this, vueCode, (0, utils_1.getVueId)(id));
        },
        async handleHotUpdate(ctx) {
            if (!ctx.file.endsWith('.md') || !vuePlugin) {
                return undefined;
            }
            const { file, read, timestamp, server, modules } = ctx;
            const { moduleGraph } = server;
            const content = await read();
            const tokens = marked_1.default.lexer(content);
            const frontMatter = (0, utils_1.getFrontMatter)(tokens);
            if (frontMatter?.changelog) {
                return modules;
            }
            const updated = [];
            const isDemo = (0, utils_1.isDemoMarkdown)(file);
            const component = isDemo
                ? (0, markdown_1.transformDemo)(tokens, file, frontMatter)
                : (0, markdown_1.transformMain)(tokens, file, frontMatter);
            const handleHotUpdate = 'handler' in vuePlugin.handleHotUpdate
                ? vuePlugin.handleHotUpdate.handler
                : vuePlugin.handleHotUpdate;
            if (isDemo) {
                const virtualPath = `/@virtual${file}`;
                const mods = moduleGraph.getModulesByFile(virtualPath);
                if (mods) {
                    const ret = await handleHotUpdate({
                        file: (0, utils_1.getVueId)(virtualPath),
                        timestamp,
                        modules: [...mods],
                        server,
                        read: () => (0, descriptor_1.getDescriptor)(virtualPath),
                    });
                    updated.push(...(ret || []));
                }
            }
            // reload the content component
            const ret = await handleHotUpdate({
                file: (0, utils_1.getVueId)(file),
                timestamp,
                modules,
                server,
                read: () => component,
            });
            return [...updated, ...(ret || [])];
        },
    };
    return docPlugin;
}
exports.default = vueMdPlugin;
//# sourceMappingURL=index.js.map