"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.transformChangelog = exports.transformDemo = exports.transformMain = void 0;
const path_1 = __importDefault(require("path"));
const fs_extra_1 = __importDefault(require("fs-extra"));
const utils_1 = require("./utils");
const marked_1 = __importDefault(require("./marked"));
const vue_template_1 = require("./vue-template");
const descriptor_1 = require("./descriptor");
const parse_changelog_1 = require("./parse-changelog");
const transformMain = (tokens, filename, frontMatter) => {
    const imports = [];
    const components = [];
    for (const token of tokens) {
        if ((0, utils_1.isFileImport)(token)) {
            const componentName = (0, utils_1.toPascalCase)(`demo-${token.basename}`);
            imports.push(`import ${componentName} from '${token.filename}';`);
            components.push(componentName);
        }
    }
    const changelog = /en-US/.test(filename) ? './CHANGELOG.md' : './CHANGELOG.zh-CN.md';
    try {
        fs_extra_1.default.accessSync(path_1.default.resolve(path_1.default.dirname(filename), changelog));
        imports.push(`import _changelog from '${changelog}';`);
    }
    catch { }
    // @ts-ignore
    const html = marked_1.default.parser(tokens);
    return (0, vue_template_1.getMainVue)({ html, imports, components, data: frontMatter });
};
exports.transformMain = transformMain;
const transformDemo = (tokens, filename, frontMatter) => {
    const basename = path_1.default.basename(filename, '.md');
    const virtualPath = `/@virtual${filename}`;
    const data = {
        id: basename,
        title: frontMatter?.title ?? '',
        description: {},
        virtualPath,
        code: '',
    };
    for (const token of tokens) {
        if ((0, utils_1.isI18nDescription)(token)) {
            data.description[token.locale] = token.content;
        }
        else if ((0, utils_1.isCode)(token) && token.lang === 'vue') {
            (0, descriptor_1.createDescriptor)(virtualPath, token.text);
            // @ts-ignore
            data.code = marked_1.default.parser([token]);
        }
    }
    return (0, vue_template_1.getDemoVue)(data);
};
exports.transformDemo = transformDemo;
const transformChangelog = (tokens) => {
    const changelog = (0, parse_changelog_1.parseChangelog)(tokens);
    return `export default ${JSON.stringify(changelog, null, 2)};`;
};
exports.transformChangelog = transformChangelog;
//# sourceMappingURL=markdown.js.map