"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const path_1 = __importDefault(require("path"));
const compiler_sfc_1 = require("@vue/compiler-sfc");
const marked_1 = __importDefault(require("marked"));
// @ts-ignore
const helpers_1 = require("marked/src/helpers");
const js_yaml_1 = __importDefault(require("js-yaml"));
const prismjs_1 = __importDefault(require("prismjs"));
const index_1 = __importDefault(require("prismjs/components/index"));
const languages = ['shell', 'js', 'ts', 'jsx', 'tsx', 'less', 'diff'];
(0, index_1.default)(languages);
const frontMatter = {
    name: 'frontMatter',
    level: 'block',
    tokenizer(src) {
        const rule = /^```yaml\n+(.+?)\n+```(?:\n|$)/s;
        const match = rule.exec(src);
        if (match) {
            const text = match[1].trim();
            const attributes = js_yaml_1.default.load(text);
            return {
                type: 'frontMatter',
                raw: match[0],
                text,
                attributes,
            };
        }
        return undefined;
    },
    renderer() {
        // frontMatter不返回内用
        return '';
    },
};
const fileImport = {
    name: 'fileImport',
    level: 'block',
    tokenizer(src) {
        const rule = /^@import\s+(.+)(?:\n|$)/;
        const match = rule.exec(src);
        if (match) {
            const filename = match[1].trim();
            const basename = path_1.default.basename(filename, '.md');
            return {
                type: 'fileImport',
                raw: match[0],
                filename,
                basename,
            };
        }
        return undefined;
    },
    renderer(token) {
        return `<demo-${token.basename} />\n`;
    },
};
const i18nDescription = {
    name: 'i18nDescription',
    level: 'block',
    tokenizer(src) {
        const rule = /^##\s+(zh-CN|en-US)\n+(.+?)\n+---(?:\n|$)/s;
        const match = rule.exec(src);
        if (match) {
            const text = match[2].trim();
            const content = (0, marked_1.default)(text);
            return {
                type: 'i18nDescription',
                raw: match[0],
                text,
                locale: match[1],
                content,
            };
        }
        return undefined;
    },
    renderer(token) {
        return token.content;
    },
};
marked_1.default.setOptions({
    highlight(code, lang, callback) {
        if (lang === 'vue') {
            const { descriptor, errors } = (0, compiler_sfc_1.parse)(code);
            const { script, styles } = descriptor;
            let htmlContent = code;
            const hasStyle = Boolean(styles.length > 0);
            if (script?.content) {
                htmlContent = htmlContent.replace(script.content, '$script$');
            }
            if (hasStyle) {
                styles.forEach((style, index) => {
                    htmlContent = htmlContent.replace(style.content, `$style-${index}$`);
                });
            }
            let highlighted = prismjs_1.default.highlight(htmlContent, prismjs_1.default.languages.html, 'html');
            if (script?.content) {
                const lang = script.lang ?? 'js';
                const highlightedScript = prismjs_1.default.highlight(script.content, prismjs_1.default.languages[lang], lang);
                highlighted = highlighted.replace('$script$', highlightedScript);
            }
            if (hasStyle) {
                styles.forEach((style, index) => {
                    const lang = style.lang ?? 'css';
                    const highlightedStyle = prismjs_1.default.highlight(style.content, prismjs_1.default.languages[lang], lang);
                    highlighted = highlighted.replace(`$style-${index}$`, highlightedStyle);
                });
            }
            return highlighted;
        }
        if (languages.includes(lang)) {
            return prismjs_1.default.highlight(code, prismjs_1.default.languages[lang], lang);
        }
        return code;
    },
});
marked_1.default.use({
    breaks: true,
    xhtml: true,
    renderer: {
        heading(text, level, raw) {
            if (level === 2) {
                const anchor = raw.replace(/\s+/g, '-');
                return `<a-page-header level="${level}" href="${anchor}">${text}</a-page-header>`;
            }
            return `<h${level} id="${raw}">${text}</h${level}>`;
        },
        link(href, title, text) {
            href = (0, helpers_1.cleanUrl)(this.options.sanitize, this.options.baseUrl, href);
            if (href === null) {
                return text;
            }
            let out = `<a class="link" href="${(0, helpers_1.escape)(href)}"`;
            if (title) {
                if (/_blank/.test(title)) {
                    out += ` target="_blank"`;
                    title = title.replace('_blank', '').trim();
                    if (title) {
                        out += ` title="${title}"`;
                    }
                }
                else {
                    out += ` title="${title}"`;
                }
            }
            out += `>${text}</a>`;
            return out;
        },
        code(code, infostring) {
            const lang = (infostring || '').match(/\S*/)?.[0];
            if (this.options.highlight) {
                const out = this.options.highlight(code, lang);
                if (out != null && out !== code) {
                    code = out;
                }
            }
            code = code.replace(/{{|}}/g, (string) => {
                if (string === '{{') {
                    return '&#123;&#123;';
                }
                return '&#125;&#125;';
            });
            code = `${code.replace(/\n$/, '')}\n`;
            if (!lang) {
                return `<pre class="code-content"><code>${code}</code></pre>\n`;
            }
            return `<pre class="code-content"><code class="${this.options.langPrefix}lang">${code}</code></pre>\n`;
        },
        table(header, body) {
            return `<div class="ant-table ant-table-bordered">
<div class="ant-table-container"><div class="ant-table-content">
<table class="component-api-table" style="table-layout: auto;">
  <colgroup>
    <col style="min-width: 120px"/>
  </colgroup>
  <thead class="ant-table-thead">${header}</thead><tbody class="ant-table-tbody">${body}</tbody>
</table></div></div></div>`;
        },
        tablerow(content) {
            return `<tr>${content}</tr>`;
        },
        tablecell(content, { header, align }) {
            if (header) {
                return `<th class="ant-table-cell">${content}</th>`;
            }
            return `<td class="ant-table-cell">${content}</td>`;
        },
    },
    // @ts-ignore @types/marked版本过低导致
    extensions: [i18nDescription, fileImport, frontMatter],
});
exports.default = marked_1.default;
//# sourceMappingURL=marked.js.map