"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getValidFilename = exports.getVueId = exports.getFrontMatter = exports.isDemoMarkdown = exports.isVirtualModule = exports.getTemplateString = exports.toPascalCase = exports.toKebabCase = exports.isSpace = exports.isI18nDescription = exports.isFileImport = exports.isHeading = exports.isCode = exports.isParagraph = void 0;
const path_1 = __importDefault(require("path"));
function isParagraph(token) {
    return token.type === 'paragraph';
}
exports.isParagraph = isParagraph;
function isCode(token) {
    return token.type === 'code';
}
exports.isCode = isCode;
function isHeading(token) {
    return token.type === 'heading';
}
exports.isHeading = isHeading;
const isFileImport = (token) => {
    return token.type === 'fileImport';
};
exports.isFileImport = isFileImport;
const isI18nDescription = (token) => {
    return token.type === 'i18nDescription';
};
exports.isI18nDescription = isI18nDescription;
function isSpace(token) {
    return token.type === 'space';
}
exports.isSpace = isSpace;
const toKebabCase = (string) => {
    string = string.trim();
    if (/\s\w/.test(string)) {
        string = string.replace('s(w)', (match, word) => {
            return word.toUpperCase();
        });
    }
    return string.replace(/[A-Z]/g, (match, offset) => {
        return `${offset > 0 ? '-' : ''}${match.toLowerCase()}`;
    });
};
exports.toKebabCase = toKebabCase;
const toPascalCase = (string) => {
    string = string.trim();
    return string
        .replace(/^[a-z]/, (match) => match.toLocaleUpperCase())
        .replace(/-(\w)/g, (match, p1) => {
        return p1.toLocaleUpperCase();
    });
};
exports.toPascalCase = toPascalCase;
/**
 * 将字符串转换为模板中的字符串格式
 */
const getTemplateString = (string) => {
    return `'${string.replace(/'/g, `\\'`)}'`;
};
exports.getTemplateString = getTemplateString;
const isVirtualModule = (id) => {
    return /\/@virtual/.test(id);
};
exports.isVirtualModule = isVirtualModule;
const isDemoMarkdown = (id) => {
    return /\/__demo__\//.test(id);
};
exports.isDemoMarkdown = isDemoMarkdown;
const getFrontMatter = (tokens) => {
    for (const token of tokens) {
        if (token.type === 'frontMatter') {
            return token.attributes;
        }
    }
    return undefined;
};
exports.getFrontMatter = getFrontMatter;
const getVueId = (id) => {
    return id.replace('.md', '.vue');
};
exports.getVueId = getVueId;
const getValidFilename = (filename) => {
    return path_1.default.extname(filename) ? filename : `${filename}.md`;
};
exports.getValidFilename = getValidFilename;
//# sourceMappingURL=utils.js.map