"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getDemoVue = exports.getMainVue = void 0;
/**
 * 获取Main组件的Vue代码
 */
const utils_1 = require("./utils");
const getMainVue = ({ html, imports, components, data, }) => `<template>
  <arco-article v-bind="data" :changelog="changelog">
    ${html}
  </arco-article>
</template>

<script lang="ts">
import { defineComponent } from 'vue';
import { useLocale } from '@ent-core/locales';
${imports.join('\n')};

export default defineComponent({
  name: 'ArcoMain',
  components: { ${components.join(',')} },
  setup() {
    const { getLocale: locale } = useLocale();
    const data = ${JSON.stringify(data)};
    const getMessage = (zh, en) => {
      return locale.value === 'zh_CN' ? zh : en;
    };
    const changelog = typeof _changelog === 'undefined' ? undefined : _changelog;

    return {
      locale,
      data,
      changelog,
      getMessage
    };
  }
});
</script>
`;
exports.getMainVue = getMainVue;
const getDemoVue = ({ id, virtualPath, title, description, code, }) => `<template>
  <code-block id="${id}" :title="getMessage(${(0, utils_1.getTemplateString)(title['zh-CN'])}, ${(0, utils_1.getTemplateString)(title['en-US'])})">
    <template v-if="locale === 'zh_CN'" #description>
      ${description['zh-CN'] ?? ''}
    </template>
    <template v-else #description>
      ${description['en-US'] ?? ''}
    </template>
    <cell-demo>
      <virtual-demo />
    </cell-demo>
    <cell-code>
      ${code}
    </cell-code>
  </code-block>
</template>
<script lang="ts">
import { defineComponent } from 'vue';
import { useLocale } from '@ent-core/locales';
import VirtualDemo from '${virtualPath}';

export default defineComponent({
  name: 'ArcoDemo',
  components: { VirtualDemo },
  setup() {
    const { getLocale: locale } = useLocale();
    const getMessage = (zh, en) => {
      return {'zh_CN': zh, 'en': en};
    };

    return {
      locale,
      getMessage
    };
  }
});
</script>
`;
exports.getDemoVue = getDemoVue;
//# sourceMappingURL=vue-template.js.map