"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const nodePath = __importStar(require("path"));
const fs_1 = __importDefault(require("fs"));
const bt = __importStar(require("@babel/types"));
const propHandler_1 = require("vue-docgen-api/dist/script-handlers/propHandler");
const getPropsFilter_1 = __importDefault(require("./getPropsFilter"));
const resolveImport_1 = __importDefault(require("./resolveImport"));
const resolve_var_1 = __importDefault(require("./resolve-var"));
function resolveImportFile(cwd, fileName, types = ['ts']) {
    // eslint-disable-next-line guard-for-in
    for (const ext in types) {
        const result = nodePath.resolve(cwd, `${fileName}.${types[ext]}`);
        if (fs_1.default.existsSync(result)) {
            return result;
        }
    }
    return undefined;
}
/**
 * Extract props information form an object-style VueJs component
 * @param documentation
 * @param path
 */
async function propExtHandler(documentation, path, ast, opt) {
    if (bt.isObjectExpression(path.node)) {
        const propsPath = path
            .get('properties')
            .filter((p) => bt.isObjectProperty(p.node) && (0, getPropsFilter_1.default)('props')(p));
        // if no prop return
        if (!propsPath.length) {
            return Promise.resolve();
        }
        const modelPropertyName = getModelPropName(path);
        const propsValuePath = propsPath[0].get('value');
        if (bt.isIdentifier(propsValuePath.node)) {
            const varName = propsValuePath.node.name;
            //从vue文件定义的变量查找props
            const varDesc = ast.program.body
                .filter((n) => n.type === 'VariableDeclaration')
                .flatMap((val) => {
                const n = val;
                return n.declarations;
            })
                .find((val) => {
                const n = val;
                return n.id.name === varName;
            });
            if (varDesc && varDesc.init && varDesc.init.type === 'ObjectExpression') {
                const vals = (0, resolve_var_1.default)(ast);
                const varDescPath = vals.get(varName);
                // @ts-ignore
                await (0, propHandler_1.describePropsFromValue)(documentation, varDescPath, ast, opt, modelPropertyName);
            }
            else {
                //从import中查找定义的props
                const importDesc = ast.program.body
                    .filter((n) => n.type === 'ImportDeclaration')
                    .find((val) => {
                    const n = val;
                    return n.specifiers.map((m) => m.local.name).includes(varName);
                });
                if (importDesc) {
                    const cwd = nodePath.dirname(opt.filePath);
                    const importFile = resolveImportFile(cwd, importDesc.source.value);
                    const nodePaths = (0, resolveImport_1.default)(importFile);
                    if (nodePaths.has(varName)) {
                        const p = nodePaths.get(varName);
                        // @ts-ignore
                        await (0, propHandler_1.describePropsFromValue)(documentation, 
                        // @ts-ignore
                        p, ast, opt, modelPropertyName);
                    }
                }
            }
        }
    }
    return Promise.resolve();
}
exports.default = propExtHandler;
/**
 * extract the property model.prop from the component object
 * @param path component NodePath
 * @returns name of the model prop, null if none
 */
function getModelPropName(path) {
    const modelPath = path
        .get('properties')
        .filter((p) => bt.isObjectProperty(p.node) && (0, getPropsFilter_1.default)('model')(p));
    if (!modelPath.length) {
        return null;
    }
    const modelValue = modelPath.length && modelPath[0].get('value');
    if (!bt.isObjectExpression(modelValue.node)) {
        return null;
    }
    const modelPropertyNamePath = modelValue
        .get('properties')
        .filter((p) => bt.isObjectProperty(p.node) && (0, getPropsFilter_1.default)('prop')(p));
    if (!modelPropertyNamePath.length) {
        return null;
    }
    const valuePath = modelPropertyNamePath[0].get('value');
    return bt.isStringLiteral(valuePath.node) ? valuePath.node.value : null;
}
//# sourceMappingURL=propExtHandler.js.map