"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const utils_1 = require("../utils");
const tmpl = (props, { isInterface = false }, lang) => {
    const displayableProps = props.filter(({ name, description, tags }) => description || ['disabled'].includes(name) || lang in (tags ?? {}));
    const hasVersion = displayableProps.some((prop) => prop?.tags?.version);
    const content = displayableProps
        .map((prop) => {
        const { name, type, values, defaultValue, required, tags } = prop;
        let { description } = prop;
        if (tags?.[lang]?.length) {
            description = tags[lang][0].description;
        }
        // 支持通过名为 type 的 tag 重新定义字段的类型
        const fixedType = (0, utils_1.cleanStr)(
        // tag 的 ts 类型有问题，所以忽略 ts 规则检查
        // @ts-ignore-next-line
        (0, utils_1.trimStr)(tags?.type?.[0]?.description || type?.name || ''));
        const getName = () => `${isInterface ? name : (0, utils_1.toKebabCase)(name)}${tags?.vModel || name === 'modelValue' ? ' **(v-model)**' : ''}${required ? (lang === 'zh' ? ' **(必填)**' : ' **(required)**') : ''}`;
        const getDescription = () => {
            if (!description && name === 'disabled') {
                return lang === 'zh' ? '是否禁用' : 'Whether to disable';
            }
            return (0, utils_1.escapeCharacter)((0, utils_1.trimStr)(description || ''));
        };
        const getType = () => {
            if (values) {
                return (0, utils_1.escapeCharacter)(values
                    .map((item) => {
                    const fixItem = fixedType === 'string' ? `'${(0, utils_1.unquote)(item)}'` : item;
                    return fixItem;
                })
                    .join(' | '));
            }
            return (0, utils_1.escapeCharacter)(fixedType);
        };
        const getDefaultValue = () => {
            if (tags?.defaultValue) {
                // @ts-ignore-next-line
                return tags.defaultValue[0]?.description;
            }
            if (defaultValue?.value === 'undefined') {
                return '-';
            }
            const regForArrayDefaultValue = /^\(\)\s*=>\s*(\[[^]*\]*\])$/;
            if ((fixedType.includes('[]') ||
                fixedType.includes('Array') ||
                fixedType.includes('array')) &&
                defaultValue?.func &&
                regForArrayDefaultValue.test(defaultValue.value)) {
                return (0, utils_1.cleanStr)(defaultValue.value.match(regForArrayDefaultValue)?.[1] || '');
            }
            if (fixedType === 'boolean') {
                return (0, utils_1.cleanStr)(defaultValue?.value || 'false');
            }
            return defaultValue?.value || '-';
        };
        let lineContent = `|${getName()}|${getDescription()}|\`${getType()}\`|\`${getDefaultValue()}\`|`;
        if (hasVersion) {
            // tag 的 ts 类型有问题，所以忽略 ts 规则检查
            // @ts-ignore-next-line
            const version = tags?.version?.[0]?.description;
            lineContent += `${version || ''}|`;
        }
        return lineContent;
    })
        .join('\n');
    return {
        hasVersion,
        content,
    };
};
exports.default = (props, options, lang = 'zh') => {
    const { content, hasVersion } = tmpl(props, options, lang);
    if (!content)
        return '';
    let header = ['', ''];
    if (lang === 'en') {
        header = options.isInterface
            ? ['|Name|Description|Type|Default|', '|---|---|---|:---:|']
            : ['|Attribute|Description|Type|Default|', '|---|---|---|:---:|'];
        if (hasVersion) {
            header[0] += 'version|';
            header[1] += ':---|';
        }
    }
    else {
        header = ['|参数名|描述|类型|默认值|', '|---|---|---|:---:|'];
        if (hasVersion) {
            header[0] += '版本|';
            header[1] += ':---|';
        }
    }
    return `
${header[0]}
${header[1]}
${content}
`;
};
//# sourceMappingURL=props.js.map