"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.pathRewriter = void 0;
const path_1 = __importDefault(require("path"));
const promises_1 = __importDefault(require("fs/promises"));
const vueCompiler = __importStar(require("vue/compiler-sfc"));
const consola_1 = __importDefault(require("consola"));
const rimraf_1 = require("rimraf");
const ts_morph_1 = require("ts-morph");
const fast_glob_1 = __importDefault(require("fast-glob"));
const fs_extra_1 = require("fs-extra");
const chalk_1 = __importDefault(require("chalk"));
const vite_1 = require("vite");
const exclude_files_1 = require("../../utils/exclude-files");
/**
 * fork = require( https://github.com/egoist/vue-dts-gen/blob/main/src/index.ts
 */
const pathRewriter = () => {
    return (id) => {
        //id = id.replaceAll(`${EP_PREFIX}/theme`, 'fe-ent-core/theme');
        id = id.replaceAll(`@ent-core/`, `fe-ent-core/es/`);
        return id;
    };
};
exports.pathRewriter = pathRewriter;
const cwd = process.cwd();
const projRoot = (0, vite_1.searchForWorkspaceRoot)(cwd);
const TSCONFIG_PATH = path_1.default.resolve(cwd, 'tsconfig.json');
const outDir = path_1.default.resolve(cwd, 'dist', 'types');
const build = async () => {
    consola_1.default.log(`Run in dir: ${process.cwd()}`);
    const project = new ts_morph_1.Project({
        compilerOptions: {
            emitDeclarationOnly: true,
            outDir,
            baseUrl: cwd,
            rootDir: cwd,
            skipLibCheck: true,
            preserveSymlinks: true,
            noImplicitAny: false,
        },
        tsConfigFilePath: TSCONFIG_PATH,
        skipAddingFilesFromTsConfig: true,
    });
    const sourceFiles = await addSourceFiles(project);
    consola_1.default.success('Added source files');
    typeCheck(project);
    consola_1.default.success('Type check passed!');
    await project.emit({
        emitOnlyDtsFiles: true,
    });
    const tasks = sourceFiles.map(async (sourceFile) => {
        const relativePath = path_1.default.relative(cwd, sourceFile.getFilePath());
        consola_1.default.log(chalk_1.default.yellow(`Generating definition for file: ${chalk_1.default.bold(relativePath)}`));
        const emitOutput = sourceFile.getEmitOutput();
        const emitFiles = emitOutput.getOutputFiles();
        if (emitFiles.length === 0) {
            consola_1.default.warn(`Emit no file: ${chalk_1.default.bold(relativePath)}`);
        }
        const subTasks = emitFiles.map(async (outputFile) => {
            const filepath = outputFile.getFilePath();
            await promises_1.default.mkdir(path_1.default.dirname(filepath), {
                recursive: true,
            });
            await promises_1.default.writeFile(filepath, (0, exports.pathRewriter)()(outputFile.getText()), 'utf8');
            consola_1.default.log(chalk_1.default.green(`Definition for file: ${chalk_1.default.bold(relativePath)} generated`));
        });
        await Promise.all(subTasks);
    });
    await Promise.all(tasks);
};
async function addSourceFiles(project) {
    project.addSourceFileAtPath(path_1.default.resolve(projRoot, 'typings/support.d.ts'));
    const filePaths = (0, exclude_files_1.excludeFiles)(await (0, fast_glob_1.default)(['**/*.{tsx,ts,vue}'], {
        cwd,
        absolute: false,
        onlyFiles: true,
    })).map((file) => `${process.cwd()}/${file}`);
    const sourceFiles = [];
    await Promise.all([
        ...filePaths.map(async (file) => {
            if (file.endsWith('.vue')) {
                const content = await promises_1.default.readFile(file, 'utf-8');
                const sfc = vueCompiler.parse(content);
                const { script, scriptSetup } = sfc.descriptor;
                if (script || scriptSetup) {
                    let content = '';
                    let isTS = false;
                    let isTSX = false;
                    if (scriptSetup) {
                        const compiled = vueCompiler.compileScript(sfc.descriptor, {
                            id: 'xxx',
                        });
                        content += compiled.content;
                        if (scriptSetup.lang === 'ts')
                            isTS = true;
                        if (scriptSetup.lang === 'tsx')
                            isTSX = true;
                    }
                    else if (script && script.content) {
                        content += script.content;
                        if (script.lang === 'ts')
                            isTS = true;
                        if (script.lang === 'tsx')
                            isTSX = true;
                    }
                    if (content.length == 0) {
                        consola_1.default.error(`Error Get Content : ${chalk_1.default.bold(file)}`);
                    }
                    else {
                        const sourceFile = project.createSourceFile(path_1.default.relative(process.cwd(), file) + (isTS ? '.ts' : isTSX ? '.tsx' : '.js'), content);
                        sourceFiles.push(sourceFile);
                    }
                }
            }
            else {
                const sourceFile = project.addSourceFileAtPath(file);
                sourceFiles.push(sourceFile);
            }
        }),
    ]);
    return sourceFiles;
}
function typeCheck(project) {
    const diagnostics = project.getPreEmitDiagnostics();
    if (diagnostics.length > 0) {
        consola_1.default.error(project.formatDiagnosticsWithColorAndContext(diagnostics));
        const err = new Error('Failed to generate dts.');
        consola_1.default.error(err);
        throw err;
    }
}
async function default_1(library) {
    await build();
    (0, fs_extra_1.rmSync)(path_1.default.resolve(outDir, 'tsconfig.tsbuildinfo'));
    if (!library) {
        (0, fs_extra_1.ensureDirSync)(path_1.default.resolve(cwd, 'es'));
        (0, fs_extra_1.copySync)(outDir, path_1.default.resolve(cwd, 'es'), {
            recursive: true,
        });
        (0, fs_extra_1.ensureDirSync)(path_1.default.resolve(cwd, 'lib'));
        (0, fs_extra_1.copySync)(outDir, path_1.default.resolve(cwd, 'lib'), {
            recursive: true,
        });
        rimraf_1.rimraf.sync(outDir);
    }
}
exports.default = default_1;
//# sourceMappingURL=index.js.map