"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.wrapperEnv = exports.getEnvConfig = void 0;
const node_path_1 = require("node:path");
const dotenv_1 = __importDefault(require("dotenv"));
const fs_extra_1 = require("fs-extra");
/**
 * 获取当前环境下生效的配置文件名
 */
function getConfFiles() {
    const script = process.env.npm_lifecycle_script;
    const reg = new RegExp('--mode ([a-z_\\d]+)');
    const result = reg.exec(script);
    if (result) {
        const mode = result[1];
        return ['.env', `.env.${mode}`];
    }
    return ['.env', '.env.production'];
}
/**
 * Get the environment variables starting with the specified prefix
 * @param match prefix
 * @param confFiles ext
 */
async function getEnvConfig(match = 'VITE_', confFiles = getConfFiles()) {
    let envConfig = {};
    for (const confFile of confFiles) {
        try {
            const envPath = await (0, fs_extra_1.readFile)((0, node_path_1.join)(process.cwd(), confFile), { encoding: 'utf8' });
            const env = dotenv_1.default.parse(envPath);
            envConfig = { ...envConfig, ...env };
        }
        catch (e) {
            console.error(`Error in parsing ${confFile}`, e);
        }
    }
    const reg = new RegExp(`^(${match})`);
    const buildReg = new RegExp('^VITE_BUILD_');
    Object.keys(envConfig).forEach((key) => {
        if (!reg.test(key) || buildReg.test(key)) {
            Reflect.deleteProperty(envConfig, key);
        }
    });
    return envConfig;
}
exports.getEnvConfig = getEnvConfig;
function wrapperEnv(envConf, mode) {
    const ret = {};
    for (const envName of Object.keys(envConf)) {
        let realValue = envConf[envName].replace(/\\n/g, '\n');
        realValue = realValue === 'true' ? true : realValue === 'false' ? false : realValue;
        if (envName === 'VITE_PORT') {
            realValue = Number(realValue);
        }
        ret[envName] = realValue;
        if (typeof realValue === 'string') {
            process.env[envName] = realValue;
        }
        else if (typeof realValue === 'object') {
            process.env[envName] = JSON.stringify(realValue);
        }
    }
    ret['NODE_ENV'] = mode;
    return ret;
}
exports.wrapperEnv = wrapperEnv;
//# sourceMappingURL=env.js.map